import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class CounterView extends View
{
   public static final int FrameWidth  = 400;
   public static final int FrameHeight = 400;

   private Frame  myWindow;
   private Label  myLabel;

   public CounterView( Counter whatIWatch )
   {
      super( whatIWatch );

      myWindow = new Frame();
      myLabel  = new Label( String.valueOf( whatIWatch.value() ) );

      Button incrementButton = new Button( "INCREMENT" );
      Button decrementButton = new Button( "DECREMENT" );
      Button resetButton     = new Button( "RESET" );
      Button quitButton      = new Button( "QUIT" );

      myWindow.setTitle( "I am watching a model." );
      myWindow.setSize ( FrameWidth, FrameHeight );

      myLabel.setFont( new Font( "SansSerif", Font.BOLD, 72 ) );
      myLabel.setAlignment( Label.CENTER );

      incrementButton.addActionListener( new IncrementButtonListener() );
      decrementButton.addActionListener( new DecrementButtonListener() );
      resetButton.addActionListener( new ResetButtonListener() );
      quitButton.addActionListener( new QuitButtonListener() );

      myWindow.add( "Center", myLabel );
      myWindow.add( "West", incrementButton);
      myWindow.add( "East", decrementButton);
      myWindow.add( "North", resetButton);
      myWindow.add( "South", quitButton);
   }

   public void update()
   {
      myLabel.setText( String.valueOf( getCounter().value() ) ); 
      myWindow.repaint();
   }

   public void show()
   {
      myWindow.show();
   }

   private class IncrementButtonListener implements ActionListener
   {
      public void actionPerformed (ActionEvent e)
      {
         getCounter().increment();
	 myWindow.repaint();
      }
   }

   private class DecrementButtonListener implements ActionListener
   {
      public void actionPerformed (ActionEvent e)
      {
         getCounter().decrement();
	 myWindow.repaint();
      }
   }

   private class ResetButtonListener implements ActionListener
   {
      public void actionPerformed (ActionEvent e)
      {
	 getCounter().reset();
	 myWindow.repaint();
      }
   }

   private class QuitButtonListener implements ActionListener
   {
      public void actionPerformed (ActionEvent e)
      {
         // System.exit( 0 );
         myWindow.dispose();
      }
   }

   private Counter getCounter()
   {
      return (Counter) super.getModel();
   }
}
